/*****************************************
This program builds the dataset used in subsequent analysis

*****************************************/
*Get the ABS/MBS variables

*LP SQL Query (RADAR) -- the results are collated in lp_updated.dta dataset that contains 964,137 loan originations
*SELECT loan_id, fico_orig, document_type, dti_ratio_back, dti_ratio_front, ltv_ratio, appraisal_amt, margin_rate, prod_type, prop_type, first_rate_nmon, rate_reset_nmon, pp_pen_flg, negam_flg AMORT_TERM_NMON, CLOSE_DT, INIT_RATE, LIEN_TYPE, LOAN_TYPE, LTV_COMB_RATIO, OCCUPANCY_TYPE, ORIG_AMT, PAY_RESET_NMON, PROP_ZIP, PURPOSE_TYPE_LP, SALE_PRICE_AMT, SEASONING_NMON, TERM_NMON, TERMINATION_TYPE FROM mbs.view_mortgage_static_mbs  WHERE prop_state IN ('IL')  ORDER BY loan_id
*SELECT loan_id, fico_orig, document_type, dti_ratio_back, dti_ratio_front, ltv_ratio, appraisal_amt, margin_rate, prod_type, prop_type, first_rate_nmon, rate_reset_nmon, pp_pen_flg, negam_flg AMORT_TERM_NMON, CLOSE_DT, INIT_RATE, LIEN_TYPE, LOAN_TYPE, LTV_COMB_RATIO, OCCUPANCY_TYPE, ORIG_AMT, PAY_RESET_NMON, PROP_ZIP, PURPOSE_TYPE_LP, SALE_PRICE_AMT, SEASONING_NMON, TERM_NMON, TERMINATION_TYPE FROM abs.view_mortgage_static_abs  WHERE prop_state IN ('IL')  ORDER BY loan_id

* import delimited "O:\PROJ_LIB\hb4050\contractchoice\updated data pulls\mbs052625_6041484763002static.csv"
* sort loan_id
* save temp

* append using temp
* close_dt is formatted as string in the pull, dropped here to avoid using keepusing() during merge
* drop close_dt
* replace loan_id = strrtrim(loan_id)
* isid loan_id
* save "O:\PROJ_LIB\hb4050\contractchoice\data\lp_updated.dta", replace


******************************************
cd O:/PROJ_LIB/hb4050

* set data extension for use in subsequent analysis

* CHOICE SET: {notype; notype_fico; all_fico}
* notype 		== HMDA-LP matched loans, not using lender type to build the synthetic sample
* notype_fico 	== HMDA-LP matched loans, not using lender type BUT using FICO bins to build the synthetic sample
* all_fico		== all LP loans, not using lender type BUT using FICO bins to build the synthetic sample

local extension notype_fico

capture drop duplicate*

* check whether loan_id is a unique identifier
isid loan_id

drop if close_dt==.

*Chicago zip codes in the original dataset: 56 zip codes altogether; some are just P.O.Box zips like O'Hare and Merchandise Mart
g k=0
replace k=1 if inlist(zcta,60601,60602,60603,60604,60605,60606,60607,60608,60609)
replace k=1 if inlist(zcta,60610,60611,60612,60613,60614,60615,60616,60617,60618)
replace k=1 if inlist(zcta,60619,60620,60621,60622,60623,60624,60625,60626,60628) 
replace k=1 if inlist(zcta,60629,60630,60631,60632,60633,60634,60636,60637,60638) 
replace k=1 if inlist(zcta,60639,60640,60641,60643,60644,60645,60646,60647,60649)
replace k=1 if inlist(zcta,60651,60652,60653,60654,60655,60656,60657,60659,60660,60661,60827)

g j=(year(close_dt)>=2005 & year(close_dt)<=2007)

tab k j

* keep only Chicago zip codes during the evaluation window
keep if k==1 & j==1

drop k j

codebook loan_id
************

* define the date of treatment (HB4050 or not) by the closing date
capture drop month
g month=mofd(close_dt)

*Keep HB4050 treated and control zip codes
*see text for details on selection of the 12 control zip codes
g hb4050=(inlist(zcta, 60620, 60621, 60623, 60628, 60629, 60632, 60636, 60638, 60643, 60652))
g control=(zcta==60639 | zcta==60641 | zcta==60644 | zcta==60624 | zcta==60609 | zcta==60637 | zcta==60649 | zcta==60619 | zcta==60617 | zcta==60655 | zcta==60633 | zcta==60827)
g hb4050control=(hb4050==1 | control==1)

* Get zip-level average income from IRS
* Publicly available IRS data (originally pulled for the P&P project) are in irs_merge1.dta
* the dataset contains zip-level aggregate reported AGI and count of returns, used to construct per capita measures

sort zcta year
merge m:1 zcta year using `home'/irs_merge1, keep(match) keepusing(returns agi IRS_agi) nogen

* every loan from master is merged; no attrition in this step
sort loan_id 
merge 1:1 loan_id using `home'/lp_updated, keep(master match) keepusing(fico_orig document_type dti_ratio_back dti_ratio_front ltv_ratio appraisal_amt margin_rate prod_type prop_type first_rate_nmon rate_reset_nmon pp_pen_flg negam_flg amort_term_nmon init_rate ltv_comb_ratio pay_reset_nmon sale_price_amt seasoning_nmon term_nmon termination_type) nogen


*Get lender categorization. Produce 520 unique values of b_id
capture tostring agency, replace
g b_id=bankid+"-"+agency
sort b_id

*Get derived first delinquency dates as well as other time-varying measures
* first_delin_mbsabs2_updated.dta contains raw dates of first delinquency status as reported in servicer data

sort loan_id
merge 1:1 loan_id using `home'/first_delin_mbsabs2_updated.dta, keep(master match) nogen

*FICO categories
g lowfico=(fico<=620) if fico!=.
g midfico=(fico>620 & fico<=650) if fico!=.
g highfico=(fico>650) if fico!=. 

*Get reference mortgage rates from Freddie Mac, by month
*(mtg_rates.dta is stored in `home' = O:/PROJ_LIB/hb4050/contractchoice/data)

sort month
merge m:1 month using `home'/mtg_rates, keep(master match) nogen


#delim ;

* recall that first_delin_mbsabs2.dta is based on data that cover 2005:01-2010:12
* hence, even for the latest originations in the sample (2007:12) there are at least 36 months of performance data

*Define 18-month default ; 
g default18=(
  (first_delin_mba_9-mofd(close_dt)<=18 | 
   first_delin_mba_f-mofd(close_dt)<=18 | 
   first_delin_mba_r-mofd(close_dt)<=18 | 
   first_delin_mba_4-mofd(close_dt)<=18 | 
   first_delin_mba_5-mofd(close_dt)<=18) & 
  (first_delin_mba_9!=. | 
   first_delin_mba_f!=. | 
   first_delin_mba_r!=. | 
   first_delin_mba_4!=. | 
   first_delin_mba_5!=.  ) ) ; 

*Define 36-month default ; 
g default36=(
  (first_delin_mba_9-mofd(close_dt)<=36 | 
   first_delin_mba_f-mofd(close_dt)<=36 | 
   first_delin_mba_r-mofd(close_dt)<=36 | 
   first_delin_mba_4-mofd(close_dt)<=36 | 
   first_delin_mba_5-mofd(close_dt)<=36) & 
  (first_delin_mba_9!=. | 
   first_delin_mba_f!=. | 
   first_delin_mba_r!=. | 
   first_delin_mba_4!=. | 
   first_delin_mba_5!=.  ) ) ; 

  
*Define product type (see 20110318_hb4050_rob.do); 
g product = .;
g product2 = .;
replace product = 1 if prod_type =="10"; *FRM;
replace product = 2 if prod_type =="20"; *ARM;
replace product = 3 if inlist(prod_type, "11", "12", "13", "14", "15") | 
                       inlist(prod_type, "16", "17", "18", "19", "1C", "1I"); *IO FRM;
replace product = 4 if inlist(prod_type, "21", "22", "23", "24", "25", "26") | 
                       inlist(prod_type, "27", "28", "29", "2A", "2B", "2C", "2D", "2I"); *IO ARM;
replace product = 5 if inlist(prod_type, "50", "51", "52", "53", "54", "55", "5A", "5Z"); *BALLOON;
replace product = 6 if inlist(prod_type, "60", "61", "62", "63", "64", "6Z"); *TWO STEP;
replace product = 7 if inlist(prod_type, "70", "ZZ"); *GPARM AND OTHERS;
replace product2 = 8 if inlist(prod_type, "5A", "70"); *ARM BALLOONS & GPARM;
replace product2 = 9 if inlist(prod_type, "50", "51", "52", "53", "54", "55", "5Z"); *FIXED RATE BALLOONs;

*General product type dummy;
g frm_all=(product ==1 | product == 3 | product2 ==9 ); 
g arm_all=(product ==2 | product == 4 | product2 ==8 ); 
g io_all= (product==3 | product==4);	

#delim cr

* test validity of this classification
gen chg_rate = first_cur_int_rate - cur_int_rate
gen const_rate = (avg_cur_int_rate == min_cur_int_rate) & (avg_cur_int_rate == max_cur_int_rate)
sum chg_rate const_rate if frm_all
sum chg_rate const_rate if arm_all
sum chg_rate const_rate if io_all

drop chg_rate const_rate

g doc_low_new=document!=1 if document!=.

gen arm_rate_reset = (rate_reset > 0) if arm_all == 1

gen is_hybrid = 0
replace is_hybrid = 1 if (arm_all ==1 & first_rate <= 36) & (arm_rate_reset == 1 & first_rate > 0)

* Products that subject ONLY mid-FICO borrowers to counseling
g risk_products1 =(io_all == 1 | (is_hybrid == 1 & first_rate <= 36) | (doc_low_new == 1))

* Products that subject BOTH mid- and high-FICO borrowers to counseling	
g risk_products2 =(pp_pen=="Y" | negam=="Y")

g logvalue=ln(appraisal)
g logincome=ln(income)
g logIRSincome=ln(IRS_agi)

replace prop_type="10" if prop_type=="M"
replace prop_type="11" if prop_type=="Z"
destring prop_type, force replace

destring purpose, force replace
g refi=purpose!=1 if purpose!=. 

* define additional borrower and loan controls

g investor = 0
replace investor = 1 if occupancy_type=="3"

g second_lien = 0
replace second_lien = 1 if lien_type=="2"

g first_lien = 1 - second_lien

* for ARMs, use the contract margin rate; for FRMs, use the difference between the contract rate and the FHMLC survey benchmark rate
* note: 51 loans remain unclassified as either
g margin_alt = (arm_all * margin_rate) + (frm_all * (first_cur_int_rate - fhlmc_30yr))


* about 1% of margin_alt values are negative; some are short-term FRM, others are rounding errors. Correct these below
* the majority, however, have amort_term = 0 and prod_type=FRM (10). Resetting these margins to zero seems OK, as these loans are ow LTV and high FICO on average
replace margin_alt = 0 if margin_alt<0

* compute new measures of debt-to-income ratios using HMDA income data and mortgage payments from dynamic files
* note that these measures will be front-end by construction

* using first monthly payment only; note that tot_pmt_amt fields are largely empty, as they are reported directly by the servicer

gen dti_dynamic_first = 0
replace dti_dynamic_first =(first_sch_mnth_p_amt)/(income*1000/12) if income>0

* using average monthly payment instead
gen dti_dynamic_avg = 0
replace dti_dynamic_avg =(avg_sch_mnth_p_amt)/(income*1000/12) if income>0


* compute ratio of annual mortgage payment to loan size
gen pmt_ratio_first = 0
replace pmt_ratio_first = (12*first_sch_mnth_p_amt)/orig_amt
la var pmt_ratio_first "annual first monthly pmt / orig_amt"

gen pmt_ratio_avg = 0
replace pmt_ratio_avg = (12*avg_sch_mnth_p_amt)/orig_amt


*****************************
*Drop identifiers 

egen grouploan=group(loan_id)
*egen groupbank=group(b_id) --> need bank_id to set togehter LPS and LP datasets; once joined, can define groupbank and drop b_id

foreach X in loan_id agency bankid *hmda* *call* { 
 capture drop `X'
 }

*****************************
*Propensity score match
* call match_fico.do program

do contractchoice/match_fico
g hb4050synthetic=synthetic
tab synthetic hb4050
replace synthetic=0 if synthetic==. | hb4050==1

replace matched_grouploan = grouploan if matched_grouploan==.
la var matched_grouploan "if hb4050, grouploan of matched control; o/w grouploan"
drop k id
*****************************
*Save regression dataset

save contractchoice/data/matchvars_`extension', replace
clear



