* This program uses publicly available 2000 Census data and 2005 IRS Statistics of Income data
* to compute summary statistics for Table 1, Panel A

* Zip codes are grouped into 4 categories:

* (1) All City of Chicago zip codes that are neither in the HB4050 area, nor in the 12-zip control area
* (2) 10 zip codes subject to HB 4050
* (3) "12 HB-4050-like" zip codes that serves as one of the control groups
* (0) All other zip codes in suburban Cook County

* NOTE: Table 1, Panel A reports statistics for groups (2), (3), and (1)+(3)

* STEP 1
* read in the tract level 2000 Census file for state of Illinois


* The Census data was obtained at https://www.nhgis.org/ . When at the data
* pulling screen the geographic levels were set to Census Tracts, Years 2000,
* and the follwoing topics were selected: Total Population, Race, 
* Labor Force and Employment status, and Poverty. 

* The Census tracts to zip codes mapping was obtained through the Univesity of Missouri
* MABLE website at http://mcdc.missouri.edu/applications/geocorr2000.html 

* Using the following filters: 
* State: Illinois
* 2000 Census Tract to 2000 Zip/ZCTA
* Weighing Variable of Population (2000 Census)
* Using the County Code of 17031 for Cook County 

* The resulting dataset is stored in finalCensusDataset.csv

import delimited "C:\Users\g1exa01\Dropbox (Research)\AEJ Policy Submission Materials\\finalCensusDataset.csv", bindquote(nobind) asdouble

drop if zipcode == "#N/A"
 
destring zipcode, replace
destring groupnum, replace
destring afact, replace

* allocate tract level variables to zipcode using population-based aFact values

gen pop = totpop * afact

* expressed in number of individuals
gen minority = (totpop - white) * afact
gen below_pov = numbelowpov * afact

gen employed = totemploy * afact
gen unemployed = totunemploy * afact

gen households = tothouseholds * afact

preserve
collapse (sum) pop minority below_pov employed unemployed households (first) groupnum if groupnum > 0, by(zipcode)

table groupnum if groupnum > 0, c(sum pop sum minority sum below_pov sum households)
table groupnum  if groupnum > 0, c(sum pop sum employed sum unemployed)

*** Next, bring in data from IRS SOI zip code data for 2005
use "C:\Users\g1exa01\Dropbox (Research)\AEJ Policy Submission Materials\2005 IL zipcodes SOI.dta", clear
sort zipcode

merge zipcode using "C:\Users\g1exa01\Dropbox (Research)\AEJ Policy Submission Materials\zip mapping Cook Co.dta", _merge(m1)

tabulate m1
keep if m1==3

destring groupnum, replace

* get total counts of tax returns and their aggregate adjusted gross income (AGI)
table groupnum if groupnum>0, c(sum n1 sum a00100)

* get total counts of tax returns and their aggregate adjusted gross income (AGI) for
* a subset of households with AGI <= $50,000

table groupnum if groupnum>0 & agi_class<=3, c(sum n1 sum a00100)


